"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Represents a token within a sentence
 */
class Token {
    constructor(text, occurrence, occurrences) {
        this.text = text;
        this.occurrence = occurrence;
        this.occurrences = occurrences;
    }
    /**
     * Checks if this token equals another one.
     * @param {Token} token
     * @return {boolean}
     */
    equals(token) {
        return token.text === this.text && token.occurrence === this.occurrence && token.occurrences === this.occurrences;
    }
}
exports.Token = Token;
/**
 * Represents a sentence
 */
class Sentence {
    constructor() {
        this._text = "";
        this._tokens = [];
        this._context = "";
    }
    get text() {
        return this._text;
    }
    get tokens() {
        return this._tokens;
    }
    get context() {
        return this._context;
    }
    /**
     * Loads a sentence from json
     * @param json
     * @return {Sentence}
     */
    static fromJson(json) {
        const sentence = new Sentence();
        for (const t of json.tokens) {
            sentence._tokens.push(new Token(t.text, t.occurrence, t.occurrences));
        }
        sentence._text = json.text;
        sentence._context = json.metadata.contextId;
        return sentence;
    }
}
exports.Sentence = Sentence;
/**
 * represents an alignment
 */
class Alignment {
    constructor(sourceNgram, targetNgram) {
        this.sourceNgram = sourceNgram;
        this.targetNgram = targetNgram;
    }
}
exports.Alignment = Alignment;
/**
 * Represents an aligned sentence
 */
class AlignedSentence {
    constructor() {
        this._source = new Sentence();
        this._target = new Sentence();
        this._alignments = [];
    }
    get source() {
        return this._source;
    }
    get target() {
        return this._target;
    }
    get alignments() {
        return this._alignments;
    }
    /**
     * Loads an aligned sentence from json
     * @param json
     * @return {AlignedSentence}
     */
    static fromJson(json) {
        const sentence = new AlignedSentence();
        sentence._source = Sentence.fromJson(json.source);
        sentence._target = Sentence.fromJson(json.target);
        for (const a of json.alignments) {
            sentence._alignments.push(new Alignment(a.sourceNgram, a.targetNgram));
        }
        return sentence;
    }
}
exports.default = AlignedSentence;
