"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Injector_1 = require("./Injector");
const fs = require("fs-extra");
/**
 * Reads data from files and writes the aligned USFM to a file.
 * @param {string} alignmentsFile - path to the alignments file
 * @param {string} usfmFile - path to the usfm file
 * @param {string} outputFile - path to the output usfm file
 */
module.exports.alignFiles = (alignmentsFile, usfmFile, outputFile) => {
    const alignments = fs.readFileSync(alignmentsFile).toString();
    const usfm = fs.readFileSync(usfmFile).toString();
    const alignmentsJson = JSON.parse(alignments);
    const alignedUSFM = Injector_1.alignUSFM3(alignmentsJson, usfm);
    fs.writeFileSync(outputFile, alignedUSFM);
};
/**
 * Aligns USFM and returns the result
 * @param {string} alignments
 * @param {string} usfm
 * @return {string}
 */
module.exports.align = (alignments, usfm) => {
    return Injector_1.alignUSFM3(JSON.parse(alignments), usfm);
};
